@@ -1,14 +1,14 @@
 
 # The R Commander and command logger
 
-# last modified 2011-11-16 by J. Fox
+# last modified 2011-12-22 by J. Fox
 #  applied patch to improve window behaviour supplied by Milan Bouchet-Valat 2011-09-22
 #   slight changes 12 Aug 04 by Ph. Grosjean
 #   changes 21 June 2007 by Erich Neuwirth for Excel support (marked EN)
 #   modified 17 December 2008 by Richard Heiberger  ##rmh
 
 Commander <- function(){
-	RcmdrVersion <- "1.7-3"
+	RcmdrVersion <- "1.8-1"
 	##    DESCRIPTION <- readLines(file.path(.find.package("Rcmdr"), "DESCRIPTION")[1])
 	##    RcmdrVersion <- trim.blanks(sub("^Version:", "",
 	##        grep("^Version:", D, value=TRUE)))
@@ -141,6 +141,7 @@ Commander <- function(){
 	putRcmdr("outputFileName", NULL)
 	putRcmdr("saveFileName", NULL)
 	putRcmdr("modelNumber", 0)
+	putRcmdr("reset.model", FALSE)
 	putRcmdr("rgl", FALSE)
 	putRcmdr("Identify3d", NULL)
 	setOption("log.font.size", if (.Platform$OS.type == "windows") 10 else 12)
@@ -155,8 +156,9 @@ Commander <- function(){
 	else setOption("default.contrasts", c("contr.treatment", "contr.poly"))
 	setOption("log.commands", TRUE)
 	setOption("console.output", FALSE)
-	setOption("dialog.memory", FALSE)
+	setOption("retain.selections", TRUE)
 	putRcmdr("dialog.values", list())
+	putRcmdr("savedTable", NULL)
 	log.height <- as.character(setOption("log.height", if (!getRcmdr("log.commands")) 0 else 10, global=FALSE))
 	log.width <- as.character(setOption("log.width", 80, global=FALSE))
 	output.height <- as.character(setOption("output.height",
