@@ -1,6 +1,6 @@
 # Statistics Menu dialogs
 
-# last modified 2011-10-13 by J. Fox
+# last modified 2011-12-22 by J. Fox
 
     # Summaries menu
     
@@ -79,6 +79,7 @@ numericalSummaries <- function(){ # dialog memory 2011-06-27  J. Fox
 			initial.skewness="0", initial.kurtosis="0", initial.type="2",
 			initial.group=NULL)
 	dialog.values <- getDialog("numericalSummaries", defaults)
+	initial.group <- dialog.values$initial.group
 	initializeDialog(title=gettextRcmdr("Numerical Summaries"))
 	xBox <- variableListBox(top, Numeric(), selectmode="multiple", title=gettextRcmdr("Variables (pick one or more)"),
 			initialSelection=varPosn(dialog.values$initial.x, "numeric"))
@@ -98,8 +99,9 @@ numericalSummaries <- function(){ # dialog memory 2011-06-27  J. Fox
 	quantiles <- tclVar(dialog.values$initial.quantiles)
 	quantilesEntry <- ttkentry(quantilesFrame, width="20", textvariable=quantiles)
 	groupsBox(recall=numericalSummaries, label=gettextRcmdr("Summarize by:"), 
-			initialLabel=gettextRcmdr("Summarize by groups"), 
-			initialGroup=dialog.values$initial.group)
+			initialLabel=if (is.null(initial.group)) gettextRcmdr("Summarize by groups") 
+					else paste(gettextRcmdr("Summarize by:"), initial.group), 
+			initialGroup=initial.group)
 	onOK <- function(){
 		x <- getSelection(xBox)
 		quants <- tclvalue(quantiles)
@@ -158,111 +160,230 @@ numericalSummaries <- function(){ # dialog memory 2011-06-27  J. Fox
 	dialogSuffix(rows=7, columns=1)
 }
 	
-frequencyDistribution <- function(){
-    initializeDialog(title=gettextRcmdr("Frequency Distributions"))
-    xBox <- variableListBox(top, Factors(), selectmode="multiple",
-        title=gettextRcmdr("Variables (pick one or more)"))
-    optionsFrame <- tkframe(top)
-    goodnessOfFitVariable <- tclVar("0")
-    goodnessOfFitCheckBox <- tkcheckbutton(optionsFrame, variable=goodnessOfFitVariable)
-    onOK <- function(){
-        x <- getSelection(xBox)
-        if (length(x) == 0){
-            errorCondition(recall=frequencyDistribution, message=gettextRcmdr("You must select a variable."))
-            return()
-            }
-        goodnessOfFit <- tclvalue(goodnessOfFitVariable)
-        if (length(x) > 1 && goodnessOfFit == "1"){
-            errorCondition(recall=frequencyDistribution, 
-                message=gettextRcmdr("Goodness-of-fit test not available when more than one variable is selected."))
-            return()
-            }
-        closeDialog()
-        .activeDataSet <- ActiveDataSet()
-        for (variable in x){
-            command <- paste("table(", .activeDataSet, "$", variable, ")", sep="")
-            logger(paste(".Table <-", command))
-            assign(".Table", justDoIt(command), envir=.GlobalEnv)
-            doItAndPrint(paste(".Table  # counts for", variable))
-            doItAndPrint(paste("round(100*.Table/sum(.Table), 2)  # percentages for", variable))
-            }
-        env <- environment()
-        if (goodnessOfFit == 1){
-            initializeDialog(subwin, title=gettextRcmdr("Goodness-of-Fit Test"))
-            hypothesisFrame <- tkframe(subwin)
-            levs <- eval(parse(text=paste("levels(", .activeDataSet, "$", x, ")", sep="")))
-            n.levs <- length(levs)
-            assign(".entry.1", tclVar(paste("1/", n.levs, sep="")), envir=env)
-            make.entries <- "labelRcmdr(hypothesisFrame, text='Hypothesized probabilities:   ')"
-            make.lev.names <- "labelRcmdr(hypothesisFrame, text='Factor levels:')"
-            for (i in 1:n.levs) {
-                entry.varname <- paste(".entry.", i, sep="")
-                assign(entry.varname, tclVar(paste("1/", n.levs, sep="")), envir=env)
-                make.entries <- paste(make.entries, ", ", "ttkentry(hypothesisFrame, width='5', textvariable=", 
-                        entry.varname, ")", sep="")
-                make.lev.names <- paste(make.lev.names, ", labelRcmdr(hypothesisFrame, text='", levs[i], "')", sep="")
-                }
-            eval(parse(text=paste("tkgrid(", make.lev.names, ", sticky='w')", sep="")), envir=env)
-            eval(parse(text=paste("tkgrid(", make.entries, ", stick='w')", sep="")), envir=env)
-            tkgrid(hypothesisFrame, sticky="w")
-            onOKsub <- function(){
-                probs <- rep(NA, n.levs)
-                for (i in 1:n.levs){
-                    entry.varname <- paste(".entry.", i, sep="")
-                    res <- try(
-                        entry <- eval(parse(text=eval(parse(text=paste("tclvalue(", entry.varname,")", sep="")), envir=env))),
-                        silent=TRUE)
-                    if (class(res) == "try-error"){
-                        errorCondition(subwin, message=gettextRcmdr("Invalid entry."))
-                        return()
-                        }
-                    if (length(entry) == 0){
-                        errorCondition(subwin, message=gettextRcmdr("Missing entry."))
-                        return()
-                        }
-                    opts <- options(warn=-1)
-                    probs[i] <- as.numeric(entry)
-                    options(opts)
-                    }
-                probs <- na.omit(probs)
-                if (length(probs) != n.levs){
-                    errorCondition(subwin, message=sprintf(gettextRcmdr("Number of valid entries (%d)\nnot equal to number levels (%d)."), length(probs), 
-                        n.levs))
-                    return()
-                    }
-                if (any(probs < 0)){
-                    errorCondition(subwin, message=gettextRcmdr("Negative probabilities not allowed."))
-                    return()
-                    }
-                if (abs(sum(probs) - 1) > 0.001){
-                    Message(message=gettextRcmdr("Probabilities rescaled to sum to 1."), type="warning")
-                    probs <- probs/sum(probs)
-                    }
-                closeDialog(subwin)
-                command <- paste("c(", paste(probs, collapse=","), ")", sep="")
-                logger(paste(".Probs <-", command))
-                assign(".Probs", justDoIt(command), envir=.GlobalEnv)
-                doItAndPrint("chisq.test(.Table, p=.Probs)")
-                logger("remove(.Probs)")
-                remove(.Probs, envir=.GlobalEnv)
-                }
-            subOKCancelHelp(subwin)
-            tkgrid(subButtonsFrame, sticky="w")
-            dialogSuffix(subwin, rows=2, columns=1, onOK=onOKsub, focus=subwin)
-            }            
-        logger("remove(.Table)") 
-        remove(.Table, envir=.GlobalEnv)  
-        tkfocus(CommanderWindow())
-        }
-    OKCancelHelp(helpSubject="table")
-    tkgrid(getFrame(xBox), sticky="nw")    
-    tkgrid(labelRcmdr(optionsFrame, 
-        text=gettextRcmdr("Chi-square goodness-of-fit test (for one variable only)")), 
-            goodnessOfFitCheckBox, sticky="w")
-    tkgrid(optionsFrame, sticky="w")
-    tkgrid(buttonsFrame, sticky="w")
-    dialogSuffix(rows=3, columns=2)
-    }
+#frequencyDistribution <- function(){
+#    initializeDialog(title=gettextRcmdr("Frequency Distributions"))
+#    xBox <- variableListBox(top, Factors(), selectmode="multiple",
+#        title=gettextRcmdr("Variables (pick one or more)"))
+#    optionsFrame <- tkframe(top)
+#    goodnessOfFitVariable <- tclVar("0")
+#    goodnessOfFitCheckBox <- tkcheckbutton(optionsFrame, variable=goodnessOfFitVariable)
+#    onOK <- function(){
+#        x <- getSelection(xBox)
+#        if (length(x) == 0){
+#            errorCondition(recall=frequencyDistribution, message=gettextRcmdr("You must select a variable."))
+#            return()
+#            }
+#        goodnessOfFit <- tclvalue(goodnessOfFitVariable)
+#        if (length(x) > 1 && goodnessOfFit == "1"){
+#            errorCondition(recall=frequencyDistribution, 
+#                message=gettextRcmdr("Goodness-of-fit test not available when more than one variable is selected."))
+#            return()
+#            }
+#        closeDialog()
+#        .activeDataSet <- ActiveDataSet()
+#        for (variable in x){
+#            command <- paste("table(", .activeDataSet, "$", variable, ")", sep="")
+#            logger(paste(".Table <-", command))
+#            assign(".Table", justDoIt(command), envir=.GlobalEnv)
+#            doItAndPrint(paste(".Table  # counts for", variable))
+#            doItAndPrint(paste("round(100*.Table/sum(.Table), 2)  # percentages for", variable))
+#            }
+#        env <- environment()
+#        if (goodnessOfFit == 1){
+#            initializeDialog(subwin, title=gettextRcmdr("Goodness-of-Fit Test"))
+#            hypothesisFrame <- tkframe(subwin)
+#            levs <- eval(parse(text=paste("levels(", .activeDataSet, "$", x, ")", sep="")))
+#            n.levs <- length(levs)
+#            assign(".entry.1", tclVar(paste("1/", n.levs, sep="")), envir=env)
+#            make.entries <- "labelRcmdr(hypothesisFrame, text='Hypothesized probabilities:   ')"
+#            make.lev.names <- "labelRcmdr(hypothesisFrame, text='Factor levels:')"
+#            for (i in 1:n.levs) {
+#                entry.varname <- paste(".entry.", i, sep="")
+#                assign(entry.varname, tclVar(paste("1/", n.levs, sep="")), envir=env)
+#                make.entries <- paste(make.entries, ", ", "ttkentry(hypothesisFrame, width='5', textvariable=", 
+#                        entry.varname, ")", sep="")
+#                make.lev.names <- paste(make.lev.names, ", labelRcmdr(hypothesisFrame, text='", levs[i], "')", sep="")
+#                }
+#            eval(parse(text=paste("tkgrid(", make.lev.names, ", sticky='w')", sep="")), envir=env)
+#            eval(parse(text=paste("tkgrid(", make.entries, ", stick='w')", sep="")), envir=env)
+#            tkgrid(hypothesisFrame, sticky="w")
+#            onOKsub <- function(){
+#                probs <- rep(NA, n.levs)
+#                for (i in 1:n.levs){
+#                    entry.varname <- paste(".entry.", i, sep="")
+#                    res <- try(
+#                        entry <- eval(parse(text=eval(parse(text=paste("tclvalue(", entry.varname,")", sep="")), envir=env))),
+#                        silent=TRUE)
+#                    if (class(res) == "try-error"){
+#                        errorCondition(subwin, message=gettextRcmdr("Invalid entry."))
+#                        return()
+#                        }
+#                    if (length(entry) == 0){
+#                        errorCondition(subwin, message=gettextRcmdr("Missing entry."))
+#                        return()
+#                        }
+#                    opts <- options(warn=-1)
+#                    probs[i] <- as.numeric(entry)
+#                    options(opts)
+#                    }
+#                probs <- na.omit(probs)
+#                if (length(probs) != n.levs){
+#                    errorCondition(subwin, message=sprintf(gettextRcmdr("Number of valid entries (%d)\nnot equal to number levels (%d)."), length(probs), 
+#                        n.levs))
+#                    return()
+#                    }
+#                if (any(probs < 0)){
+#                    errorCondition(subwin, message=gettextRcmdr("Negative probabilities not allowed."))
+#                    return()
+#                    }
+#                if (abs(sum(probs) - 1) > 0.001){
+#                    Message(message=gettextRcmdr("Probabilities rescaled to sum to 1."), type="warning")
+#                    probs <- probs/sum(probs)
+#                    }
+#                closeDialog(subwin)
+#                command <- paste("c(", paste(probs, collapse=","), ")", sep="")
+#                logger(paste(".Probs <-", command))
+#                assign(".Probs", justDoIt(command), envir=.GlobalEnv)
+#                doItAndPrint("chisq.test(.Table, p=.Probs)")
+#                logger("remove(.Probs)")
+#                remove(.Probs, envir=.GlobalEnv)
+#                }
+#            subOKCancelHelp(subwin)
+#            tkgrid(subButtonsFrame, sticky="w")
+#            dialogSuffix(subwin, rows=2, columns=1, onOK=onOKsub, focus=subwin)
+#            }            
+#        logger("remove(.Table)") 
+#        remove(.Table, envir=.GlobalEnv)  
+#        tkfocus(CommanderWindow())
+#        }
+#    OKCancelHelp(helpSubject="table")
+#    tkgrid(getFrame(xBox), sticky="nw")    
+#    tkgrid(labelRcmdr(optionsFrame, 
+#        text=gettextRcmdr("Chi-square goodness-of-fit test (for one variable only)")), 
+#            goodnessOfFitCheckBox, sticky="w")
+#    tkgrid(optionsFrame, sticky="w")
+#    tkgrid(buttonsFrame, sticky="w")
+#    dialogSuffix(rows=3, columns=2)
+#    }
+
+frequencyDistribution <- function () {
+	defaults <- list (initial.x = NULL, initial.goodnessOfFit = "0")
+	dialog.values <- getDialog ("frequencyDistribution", defaults)
+	initializeDialog(title = gettextRcmdr("Frequency Distributions"))
+	xBox <- variableListBox(top, Factors(), selectmode = "multiple", 
+			title = gettextRcmdr("Variables (pick one or more)"),
+			initialSelection = varPosn (dialog.values$initial.x, "factor"))
+	optionsFrame <- tkframe(top)
+	goodnessOfFitVariable <- tclVar(dialog.values$initial.goodnessOfFit)
+	goodnessOfFitCheckBox <- tkcheckbutton(optionsFrame, variable = goodnessOfFitVariable)
+	onOK <- function() {
+		x <- getSelection(xBox)
+		if (length(x) == 0) {
+			errorCondition(recall = frequencyDistribution, message = gettextRcmdr("You must select a variable."))
+			return()
+		}
+		goodnessOfFit <- tclvalue(goodnessOfFitVariable)
+		putDialog ("frequencyDistribution", list (initial.x = x, initial.goodnessOfFit = goodnessOfFit))
+		if (length(x) > 1 && goodnessOfFit == "1") {
+			errorCondition(recall = frequencyDistribution, message = gettextRcmdr("Goodness-of-fit test not available when more than one variable is selected."))
+			return()
+		}
+		closeDialog()
+		.activeDataSet <- ActiveDataSet()
+		for (variable in x) {
+			command <- paste("table(", .activeDataSet, "$", variable, 
+					")", sep = "")
+			logger(paste(".Table <-", command))
+			assign(".Table", justDoIt(command), envir = .GlobalEnv)
+			doItAndPrint(paste(".Table  # counts for", variable))
+			doItAndPrint(paste("round(100*.Table/sum(.Table), 2)  # percentages for", 
+							variable))
+		}
+		env <- environment()
+		if (goodnessOfFit == 1) {
+			initializeDialog(subwin, title = gettextRcmdr("Goodness-of-Fit Test"))
+			hypothesisFrame <- tkframe(subwin)
+			levs <- eval(parse(text = paste("levels(", .activeDataSet, 
+									"$", x, ")", sep = "")))
+			n.levs <- length(levs)
+			assign(".entry.1", tclVar(paste("1/", n.levs, sep = "")), 
+					envir = env)
+			make.entries <- "labelRcmdr(hypothesisFrame, text='Hypothesized probabilities:   ')"
+			make.lev.names <- "labelRcmdr(hypothesisFrame, text='Factor levels:')"
+			for (i in 1:n.levs) {
+				entry.varname <- paste(".entry.", i, sep = "")
+				assign(entry.varname, tclVar(paste("1/", n.levs, 
+										sep = "")), envir = env)
+				make.entries <- paste(make.entries, ", ", "ttkentry(hypothesisFrame, width='5', textvariable=", 
+						entry.varname, ")", sep = "")
+				make.lev.names <- paste(make.lev.names, ", labelRcmdr(hypothesisFrame, text='", 
+						levs[i], "')", sep = "")
+			}
+			eval(parse(text = paste("tkgrid(", make.lev.names, 
+									", sticky='w')", sep = "")), envir = env)
+			eval(parse(text = paste("tkgrid(", make.entries, 
+									", stick='w')", sep = "")), envir = env)
+			tkgrid(hypothesisFrame, sticky = "w")
+			onOKsub <- function() {
+				probs <- rep(NA, n.levs)
+				for (i in 1:n.levs) {
+					entry.varname <- paste(".entry.", i, sep = "")
+					res <- try(entry <- eval(parse(text = eval(parse(text = paste("tclvalue(", 
+																	entry.varname, ")", sep = "")), envir = env))), 
+							silent = TRUE)
+					if (class(res) == "try-error") {
+						errorCondition(subwin, message = gettextRcmdr("Invalid entry."))
+						return()
+					}
+					if (length(entry) == 0) {
+						errorCondition(subwin, message = gettextRcmdr("Missing entry."))
+						return()
+					}
+					opts <- options(warn = -1)
+					probs[i] <- as.numeric(entry)
+					options(opts)
+				}
+				probs <- na.omit(probs)
+				if (length(probs) != n.levs) {
+					errorCondition(subwin, message = sprintf(gettextRcmdr("Number of valid entries (%d)\nnot equal to number levels (%d)."), 
+									length(probs), n.levs))
+					return()
+				}
+				if (any(probs < 0)) {
+					errorCondition(subwin, message = gettextRcmdr("Negative probabilities not allowed."))
+					return()
+				}
+				if (abs(sum(probs) - 1) > 0.001) {
+					Message(message = gettextRcmdr("Probabilities rescaled to sum to 1."), 
+							type = "warning")
+					probs <- probs/sum(probs)
+				}
+				closeDialog(subwin)
+				command <- paste("c(", paste(probs, collapse = ","), 
+						")", sep = "")
+				logger(paste(".Probs <-", command))
+				assign(".Probs", justDoIt(command), envir = .GlobalEnv)
+				doItAndPrint("chisq.test(.Table, p=.Probs)")
+				logger("remove(.Probs)")
+				remove(.Probs, envir = .GlobalEnv)
+			}
+			subOKCancelHelp(subwin)
+			tkgrid(subButtonsFrame, sticky = "w")
+			dialogSuffix(subwin, rows = 2, columns = 1, onOK = onOKsub, 
+					focus = subwin)
+		}
+		logger("remove(.Table)")
+		remove(.Table, envir = .GlobalEnv)
+		tkfocus(CommanderWindow())
+	}
+	OKCancelHelp(helpSubject = "table", reset = "frequencyDistribution")
+	tkgrid(getFrame(xBox), sticky = "nw")
+	tkgrid(labelRcmdr(optionsFrame, text = gettextRcmdr("Chi-square goodness-of-fit test (for one variable only)")), 
+			goodnessOfFitCheckBox, sticky = "w")
+	tkgrid(optionsFrame, sticky = "w")
+	tkgrid(buttonsFrame, sticky = "w")
+	dialogSuffix(rows = 3, columns = 2)
+}
 
 #statisticsTable <- function(){
 #	initializeDialog(title=gettextRcmdr("Table of Statistics"))
@@ -319,17 +440,14 @@ statisticsTable <- function () {
 	responseBox <- variableListBox(variablesFrame, Numeric(), selectmode = "multiple", 
 			initialSelection = varPosn(dialog.values$initial.response, "numeric"),
 			title = gettextRcmdr("Response variables (pick one or more)"))
-	radioButtons(name = "statistic", buttons = c("mean", "median", 
-					"sd"), labels = gettextRcmdr(c("Mean", "Median", "Standard deviation")), 
+	statFrame <- tkframe(top)
+	radioButtons(statFrame, name = "statistic", buttons = c("mean", "median", 
+					"sd", "other"), labels = gettextRcmdr(c("Mean", "Median", "Standard deviation", "Other (specify)")), 
 			initialValue = dialog.values$initial.statistic, 
 			title = gettextRcmdr("Statistic"))
 	otherVariable <- tclVar(dialog.values$initial.other)
-	if (!(dialog.values$initial.statistic %in% c("mean", "median", "sd"))) statisticVariable <- tclVar("other")
-	otherButton <- ttkradiobutton(statisticFrame, variable = statisticVariable, 
-			value = "other")
-	otherEntry <- ttkentry(statisticFrame, width = "20", textvariable = otherVariable)
-	tkgrid(labelRcmdr(statisticFrame, text = gettextRcmdr("Other (specify)")), 
-			otherButton, otherEntry, sticky = "w")
+	otherEntry <- ttkentry(statFrame, width = "20", textvariable = otherVariable)
+	tkgrid(statisticFrame, labelRcmdr(statFrame, text ="  "), otherEntry, sticky = "sw")
 	onOK <- function() {
 		groups <- getSelection(groupBox)
 		if (0 == length(groups)) {
@@ -345,7 +463,7 @@ statisticsTable <- function () {
 		if (statistic == "other") 
 			statistic <- tclvalue(otherVariable)
 		putDialog ("statisticsTable", list(initial.group=groups, initial.response=responses, 
-						initial.statistic=statistic, initial.other = if(stat == "other") statistic else ""))  
+						initial.statistic=stat, initial.other = if(stat == "other") statistic else ""))  
 		closeDialog()
 		.activeDataSet <- ActiveDataSet()
 		groups.list <- paste(paste(groups, "=", .activeDataSet, 
@@ -364,7 +482,7 @@ statisticsTable <- function () {
 	tkgrid(getFrame(groupBox), labelRcmdr(variablesFrame, text = "    "), 
 			getFrame(responseBox), sticky = "nw")
 	tkgrid(variablesFrame, sticky = "w")
-	tkgrid(statisticFrame, sticky = "w")
+	tkgrid(statFrame, sticky = "w")
 	tkgrid(buttonsFrame, sticky = "w")
 	dialogSuffix(rows = 3, columns = 1, focus = otherEntry)
 }
@@ -508,43 +626,87 @@ correlationMatrix <- function (){
 	dialogSuffix(rows = 4, columns = 1)
 }
 	
+#correlationTest <- function(){
+#  initializeDialog(title=gettextRcmdr("Correlation Test"))
+#  xBox <- variableListBox(top, Numeric(), selectmode="multiple", title=gettextRcmdr("Variables (pick two)"))
+#  radioButtons(name="correlations", buttons=c("pearson", "spearman", "kendall"),
+#               labels=gettextRcmdr(c("Pearson product-moment", "Spearman rank-order", "Kendall's tau")),
+#               title=gettextRcmdr("Type of Correlation"))
+#  radioButtons(name="alternative", buttons=c("two.sided", "less", "greater"), values=c("two.sided", "less", "greater"),
+#               labels=gettextRcmdr(c("Two-sided", "Correlation < 0", "Correlation > 0")), title=gettextRcmdr("Alternative Hypothesis"))  
+#  onOK <- function(){
+#    alternative <- as.character(tclvalue(alternativeVariable))
+#    correlations <- as.character(tclvalue(correlationsVariable))
+#    x <- getSelection(xBox)
+#    if (2 > length(x)) {
+#      errorCondition(recall=correlationTest,
+#        message=gettextRcmdr("Fewer than 2 variables selected."))
+#      return()
+#    }
+#    if(2 < length(x)) {
+#      errorCondition(recall=correlationTest,
+#        message=gettextRcmdr("More than 2 variables selected."))
+#      return()
+#    }
+#    closeDialog()
+#    .activeDataSet <- ActiveDataSet()
+#    command <- paste("cor.test(", .activeDataSet, "$", x[1], ", ", .activeDataSet, "$", x[2],
+#        ', alternative="', alternative, '", method="', correlations, '")', sep="")
+#    doItAndPrint(command)  
+#    tkfocus(CommanderWindow())
+#  }
+#  OKCancelHelp(helpSubject="cor.test")
+#  tkgrid(getFrame(xBox), sticky="nw")
+#  tkgrid(labelRcmdr(top, text=""))
+#  tkgrid(correlationsFrame,alternativeFrame, sticky="w")
+#  tkgrid(buttonsFrame,columnspan=2,sticky="w")
+#  dialogSuffix(rows=4, columns=1)
+#}
+
 # the following dialog contributed by Stefano Calza, modified by J. Fox
-    
+
 correlationTest <- function(){
-  initializeDialog(title=gettextRcmdr("Correlation Test"))
-  xBox <- variableListBox(top, Numeric(), selectmode="multiple", title=gettextRcmdr("Variables (pick two)"))
-  radioButtons(name="correlations", buttons=c("pearson", "spearman", "kendall"),
-               labels=gettextRcmdr(c("Pearson product-moment", "Spearman rank-order", "Kendall's tau")),
-               title=gettextRcmdr("Type of Correlation"))
-  radioButtons(name="alternative", buttons=c("two.sided", "less", "greater"), values=c("two.sided", "less", "greater"),
-               labels=gettextRcmdr(c("Two-sided", "Correlation < 0", "Correlation > 0")), title=gettextRcmdr("Alternative Hypothesis"))  
-  onOK <- function(){
-    alternative <- as.character(tclvalue(alternativeVariable))
-    correlations <- as.character(tclvalue(correlationsVariable))
-    x <- getSelection(xBox)
-    if (2 > length(x)) {
-      errorCondition(recall=correlationTest,
-        message=gettextRcmdr("Fewer than 2 variables selected."))
-      return()
-    }
-    if(2 < length(x)) {
-      errorCondition(recall=correlationTest,
-        message=gettextRcmdr("More than 2 variables selected."))
-      return()
-    }
-    closeDialog()
-    .activeDataSet <- ActiveDataSet()
-    command <- paste("cor.test(", .activeDataSet, "$", x[1], ", ", .activeDataSet, "$", x[2],
-        ', alternative="', alternative, '", method="', correlations, '")', sep="")
-    doItAndPrint(command)  
-    tkfocus(CommanderWindow())
-  }
-  OKCancelHelp(helpSubject="cor.test")
-  tkgrid(getFrame(xBox), sticky="nw")
-  tkgrid(labelRcmdr(top, text=""))
-  tkgrid(correlationsFrame,alternativeFrame, sticky="w")
-  tkgrid(buttonsFrame,columnspan=2,sticky="w")
-  dialogSuffix(rows=4, columns=1)
+	defaults <- list(initial.x=NULL,initial.correlations="pearson",initial.alternative ="two.sided")
+	dialog.values <- getDialog("correlationTest", defaults)
+	initializeDialog(title=gettextRcmdr("Correlation Test"))
+	xBox <- variableListBox(top, Numeric(), selectmode="multiple", title=gettextRcmdr("Variables (pick two)"),initialSelection=varPosn(dialog.values$initial.x, "numeric"))
+	radioButtons(name="correlations", buttons=c("pearson", "spearman", "kendall"),
+			labels=gettextRcmdr(c("Pearson product-moment", "Spearman rank-order", "Kendall's tau")),
+			initialValue=dialog.values$initial.correlations, 
+			title=gettextRcmdr("Type of Correlation"))
+	radioButtons(name="alternative", buttons=c("two.sided", "less", "greater"), 
+			values=c("two.sided", "less", "greater"),
+			initialValue=dialog.values$initial.alternative, 
+			labels=gettextRcmdr(c("Two-sided", "Correlation < 0", "Correlation > 0")), 
+			title=gettextRcmdr("Alternative Hypothesis"))  
+	onOK <- function(){
+		alternative <- as.character(tclvalue(alternativeVariable))
+		correlations <- as.character(tclvalue(correlationsVariable))
+		x <- getSelection(xBox)
+		putDialog("correlationTest", list(initial.alternative=alternative, initial.correlations=correlations, initial.x=x))
+		if (2 > length(x)) {
+			errorCondition(recall=correlationTest,
+					message=gettextRcmdr("Fewer than 2 variables selected."))
+			return()
+		}
+		if(2 < length(x)) {
+			errorCondition(recall=correlationTest,
+					message=gettextRcmdr("More than 2 variables selected."))
+			return()
+		}
+		closeDialog()
+		.activeDataSet <- ActiveDataSet()
+		command <- paste("cor.test(", .activeDataSet, "$", x[1], ", ", .activeDataSet, "$", x[2],
+				', alternative="', alternative, '", method="', correlations, '")', sep="")
+		doItAndPrint(command)  
+		tkfocus(CommanderWindow())
+	}
+	OKCancelHelp(helpSubject="cor.test", reset="correlationTest")
+	tkgrid(getFrame(xBox), sticky="nw")
+	tkgrid(labelRcmdr(top, text=""))
+	tkgrid(correlationsFrame,alternativeFrame, sticky="w")
+	tkgrid(buttonsFrame,columnspan=2,sticky="w")
+	dialogSuffix(rows=4, columns=1)
 }
 
 countMissing <- function(){
