@@ -1,4 +1,4 @@
-# last modified 2011-11-16 by J. Fox
+# last modified 2011-12-22 by J. Fox
 #  applied patch to improve window behaviour supplied by Milan Bouchet-Valat 2011-09-22
 #  slight changes 12 Aug 04 by Ph. Grosjean
 
@@ -375,7 +375,8 @@ numSummary <- function(data,
 		apply(as.matrix(x), 2, stats::sd, na.rm=TRUE)
 	}
 	cv <- function(x, ...){
-		mean <- mean(x, na.rm=TRUE)
+		x <- as.matrix(x)
+		mean <- colMeans(x, na.rm=TRUE)
 		sd <- sd(x)
 		if (any(x <= 0, na.rm=TRUE)) warning("not all values are positive")
 		cv <- sd/mean
@@ -858,7 +859,7 @@ defmacro <- function(..., expr){
 
 OKCancelHelp <- defmacro(window=top, helpSubject=NULL,  model=FALSE, reset=NULL,
 		expr={
-			memory <- getRcmdr("dialog.memory")
+			memory <- getRcmdr("retain.selections")
 			buttonsFrame <- tkframe(window, borderwidth=5)
 			OKbutton <- buttonRcmdr(buttonsFrame, text=gettextRcmdr("OK"), foreground="darkgreen", width="12", command=onOK, default="active",
 					borderwidth=3)
@@ -1201,14 +1202,77 @@ subsetBox <- defmacro(window=top, subset.expression=NULL, model=FALSE,
 			tkgrid(subsetScroll, sticky="ew")
 		})
 
+#groupsBox <- defmacro(recall=NULL, label=gettextRcmdr("Plot by:"), initialLabel=gettextRcmdr("Plot by groups"),
+#		plotLinesByGroup=FALSE, positionLegend=FALSE, plotLinesByGroupsText=gettextRcmdr("Plot lines by group"),
+#		initialGroup=NULL,
+#		expr={
+#			env <- environment()
+#			.groups <- FALSE
+#			.linesByGroup <- FALSE
+#			.groupsLabel <- tclVar(paste(initialLabel, "...", sep=""))
+#			.factors <- Factors()
+#			onGroups <- function(){
+#				if (length(.factors) == 0){
+#					errorCondition(recall=recall, message=gettextRcmdr("There are no factors in the active data set."))
+#					return()
+#				}
+#				initializeDialog(subdialog, title=gettextRcmdr("Groups"))
+#				groupsBox <- variableListBox(subdialog, .factors, title=gettextRcmdr("Groups variable (pick one)"),
+#						initialSelection=varPosn(initialGroup, "factor"))
+#				if (plotLinesByGroup){
+#					linesByGroupFrame <- tkframe(subdialog)
+#					linesByGroup <- tclVar("1")
+#					linesCheckBox <- tkcheckbutton(linesByGroupFrame, variable=linesByGroup)
+#					tkgrid(labelRcmdr(linesByGroupFrame, text=plotLinesByGroupsText), linesCheckBox, sticky="w")
+#				}
+#				onOKsub <- function() {
+#					groups <- getSelection(groupsBox)
+#					if (length(groups) == 0){
+#						assign(".groups", FALSE, envir=env)
+#						tclvalue(.groupsLabel) <- paste(initialLabel, "...", sep="")
+#						tkconfigure(groupsButton, foreground="black")
+#						if (GrabFocus()) tkgrab.release(subdialog)
+#						tkdestroy(subdialog)
+#						tkwm.deiconify(top)
+#						if (GrabFocus()) tkgrab.set(top)
+#						tkfocus(top)
+#						tkwait.window(top)
+#						return()
+#					}
+#					assign(".groups", groups, envir=env)
+#					tclvalue(.groupsLabel) <- paste(label, groups)
+#					tkconfigure(groupsButton, foreground="blue")
+#					if (plotLinesByGroup) {
+#						lines <- as.character("1" == tclvalue(linesByGroup))
+#						assign(".linesByGroup", lines, envir=env)
+#					}
+#					if (GrabFocus()) tkgrab.release(subdialog)
+#					tkdestroy(subdialog)
+#					tkwm.deiconify(top)
+#					if (GrabFocus()) tkgrab.set(top)
+#					tkfocus(top)
+#					tkwait.window(top)
+#				}
+#				subOKCancelHelp()
+#				tkgrid(getFrame(groupsBox), sticky="nw")
+#				if (plotLinesByGroup) tkgrid(linesByGroupFrame, sticky="w")
+#				tkgrid(subButtonsFrame, sticky="w")
+#				if (positionLegend) tkgrid(labelRcmdr(subdialog, text=gettextRcmdr("Position legend with mouse click"), fg="blue"))
+#				dialogSuffix(subdialog, onOK=onOKsub, rows=3+plotLinesByGroup+positionLegend, columns=2, focus=subdialog)
+#			}
+#			groupsFrame <- tkframe(top)
+#			groupsButton <- tkbutton(groupsFrame, textvariable=.groupsLabel, command=onGroups, borderwidth=3)
+#			tkgrid(labelRcmdr(groupsFrame, text="    "), groupsButton, sticky="w")
+#		})
+
 groupsBox <- defmacro(recall=NULL, label=gettextRcmdr("Plot by:"), initialLabel=gettextRcmdr("Plot by groups"),
 		plotLinesByGroup=FALSE, positionLegend=FALSE, plotLinesByGroupsText=gettextRcmdr("Plot lines by group"),
-		initialGroup=NULL,
+		initialGroup=NULL, initialLinesByGroup=1,
 		expr={
 			env <- environment()
-			.groups <- FALSE
+			.groups <- if (is.null(initialGroup)) FALSE else initialGroup
 			.linesByGroup <- FALSE
-			.groupsLabel <- tclVar(paste(initialLabel, "...", sep=""))
+			.groupsLabel <- tclVar(if (!is.null(initialGroup)) initialLabel else paste(initialLabel, "...", sep=""))
 			.factors <- Factors()
 			onGroups <- function(){
 				if (length(.factors) == 0){
@@ -1220,7 +1284,7 @@ groupsBox <- defmacro(recall=NULL, label=gettextRcmdr("Plot by:"), initialLabel=
 						initialSelection=varPosn(initialGroup, "factor"))
 				if (plotLinesByGroup){
 					linesByGroupFrame <- tkframe(subdialog)
-					linesByGroup <- tclVar("1")
+					linesByGroup <- tclVar(if(initialLinesByGroup == 1) "1" else "0")
 					linesCheckBox <- tkcheckbutton(linesByGroupFrame, variable=linesByGroup)
 					tkgrid(labelRcmdr(linesByGroupFrame, text=plotLinesByGroupsText), linesCheckBox, sticky="w")
 				}
@@ -1228,7 +1292,7 @@ groupsBox <- defmacro(recall=NULL, label=gettextRcmdr("Plot by:"), initialLabel=
 					groups <- getSelection(groupsBox)
 					if (length(groups) == 0){
 						assign(".groups", FALSE, envir=env)
-						tclvalue(.groupsLabel) <- paste(initialLabel, "...", sep="")
+						tclvalue(.groupsLabel) <- paste(gettextRcmdr("Plot by groups"), "...", sep="")
 						tkconfigure(groupsButton, foreground="black")
 						if (GrabFocus()) tkgrab.release(subdialog)
 						tkdestroy(subdialog)
@@ -1261,22 +1325,25 @@ groupsBox <- defmacro(recall=NULL, label=gettextRcmdr("Plot by:"), initialLabel=
 			}
 			groupsFrame <- tkframe(top)
 			groupsButton <- tkbutton(groupsFrame, textvariable=.groupsLabel, command=onGroups, borderwidth=3)
+			if (!is.null(initial.group)) tkconfigure(groupsButton, foreground="blue")
 			tkgrid(labelRcmdr(groupsFrame, text="    "), groupsButton, sticky="w")
 		})
 
-groupsLabel <- defmacro(frame=top, groupsBox=groupsBox, columnspan=1,
-	expr={
-		groupsFrame <- tkframe(frame)
-		groupsLabel <- labelRcmdr(groupsFrame, text=gettextRcmdr("<No groups selected>"))
-		tkgrid(labelRcmdr(groupsFrame, text=gettextRcmdr("Difference: "), fg="blue"), groupsLabel, sticky="w")
-		tkgrid(groupsFrame, sticky="w", columnspan=columnspan)
-		onSelect <- function(){
-			group <- getSelection(groupsBox)
-			levels <- eval(parse(text=paste("levels(", ActiveDataSet(), "$", group, ")", sep="")))
-			tkconfigure(groupsLabel, text=paste(levels[1], "-", levels[2]))
-		}
-		tkbind(groupsBox$listbox, "<ButtonRelease-1>", onSelect)
-	})
+groupsLabel <- defmacro(frame=top, groupsBox=groupsBox, columnspan=1, initialText=NULL,
+		expr={
+			groupsFrame <- tkframe(frame)
+			.groupsLabel <- if (is.null(initialText)) gettextRcmdr("<No groups selected>") else initialText
+			groupsLabel <- labelRcmdr(groupsFrame, text=.groupsLabel)
+			tkgrid(labelRcmdr(groupsFrame, text=gettextRcmdr("Difference: "), fg="blue"), groupsLabel, sticky="w")
+			tkgrid(groupsFrame, sticky="w", columnspan=columnspan)
+			onSelect <- function(){
+				group <- getSelection(groupsBox)
+				levels <- eval(parse(text=paste("levels(", ActiveDataSet(), "$", group, ")", sep="")))
+				.groupsLabel <<- paste(levels[1], "-", levels[2])
+				tkconfigure(groupsLabel, text=.groupsLabel)
+			}
+			tkbind(groupsBox$listbox, "<ButtonRelease-1>", onSelect)
+		})
 
 #modelFormula <- defmacro(frame=top, hasLhs=TRUE, expr={
 #    checkAddOperator <- function(rhs){
@@ -2245,7 +2312,7 @@ putDialog <- function (dialog, values=NULL){
 
 getDialog <- function(dialog, defaults=NULL){
 	values <- getRcmdr("dialog.values")[[dialog]]
-	if (!getRcmdr("dialog.memory") || is.null(values)) return(defaults)
+	if (!getRcmdr("retain.selections") || is.null(values)) return(defaults)
 	else return (values)
 }
 
